==> inSilicoDb_2.4.1.tar.gz: inSilicoDb/man/getDataset.Rd <==
\name{getDataset}
\alias{getDataset}
\title{Get dataset in ExpressionSet format}
\description{
	Get dataset for a given dataset identifier and platform identifier in a specific format.
}
\usage{
getDataset(dataset, platform, ...);
}
\arguments{
  \item{dataset}{Valid dataset identifier: the GEO or InSilico DB accession code.}
  \item{platform}{The platform of the chip on which a measurement was done.
A platform is identified by its GEO accession code.}
  \item{...}{Optional arguments can be passed to the function for more specific requests:
		\describe{
 			 \item{\code{format = "CURESET"}}{File format in which the dataset should be returned. 
 			 
			Possible values:
			\itemize{
				\item{CURESET : Curated R/Bioconductor ExpressionSet. }
				\item{ESET : R/Bioconductor ExpressionSet without curation.}
			}}
  			\item{\code{features = "PROBE"}}{Type of features in which data is represented. Two possible values: "GENE" or "PROBE". By default an expression matrix containing probes is returned. 
  			%Precomputed conversions using genes instead of probes are also available if this argument is set to "GENE". This conversion was made using the \code{nsFilter} function from Bioconductors \pkg{genefilter} package.
  			}
  			\item{\code{norm = "ORIGINAL"}}{Type of normalization to use when pre-processing a dataset.
  			 
  			Possible normalizations: "ORIGINAL", "FRMA"[1], "SCAN"[2]}
 			 \item{\code{curation}}{Specific curation used to annotate a dataset.
A curation is identified by a InSilico DB Curation identifier. You can annotate datasets yourself at \url{https://insilicodb.com/app/browse} If not defined, the prefered curation of specified dataset will be used.}   
  			\item{\code{timeout = 120}}{Time (in seconds) to wait for the dataset, if it has to be generated.}
		}
 	}
 }
 \value{
 A Bioconductors ExpressionSet.
 }
 \seealso{
 \code{\link{getDatasetInfo}}
 }
\examples{
InSilicoLogin("rpackage_tester@insilicodb.com", "5c4d0b231e5cba4a0bc54783b385cc9a");
dataset.id <- "GSE4635";
platform.id <- getPlatforms(dataset.id);
eset <- getDataset(dataset.id, platform.id[[1]],
                   norm = "ORIGINAL", features = "PROBE");
print(dim(eset));
## Features  Samples 
##    22215        8 
eset <- getDataset( dataset.id, platform.id[[1]],
                   norm = "ORIGINAL", features = "GENE");
print(dim(eset));
## Features  Samples 
##    12698        8 
}

\references{
[1] MN. McCall, BM. Bolstad, and RA. Irizarry, Frozen Robust Multi-Array Analysis (fRMA),
  \emph{Biostatistics}, vol. 11, no. 2, pp. 242-253 , 2008.
  
[2] SR. Piccolo, Y. Sun, JD. Campbell, ME. Lenburg, AH. Bild, and WE. Johnson, A single-sample microarray
  normalization method to facilitate personalized-medicine workflows, \emph{Genomics}, vol. 100, no. 6, pp. 337-344, 2012.

 }

==> inSilicoDb_2.6.0.tar.gz: inSilicoDb/man/getDataset.Rd <==
\name{getDataset}
\alias{getDataset}
\title{Get dataset in ExpressionSet format}
\description{
	Get dataset for a given dataset identifier and platform identifier in a specific format.
}
\usage{
getDataset(dataset, platform, ...);
}
\arguments{
  \item{dataset}{Valid dataset identifier: the GEO or InSilico DB accession code.}
  \item{platform}{The platform of the chip on which a measurement was done.
A platform is identified by its GEO accession code.}
  \item{...}{Optional arguments can be passed to the function for more specific requests:
		\describe{
 			 \item{\code{format = "CURESET"}}{File format in which the dataset should be returned. 
 			 
			Possible values:
			\itemize{
				\item{CURESET : Curated R/Bioconductor ExpressionSet. }
				\item{ESET : R/Bioconductor ExpressionSet without curation.}
			}}
  			\item{\code{features = "PROBE"}}{Type of features in which data is represented. Two possible values: "GENE" or "PROBE". By default an expression matrix containing probes is returned. 
  			%Precomputed conversions using genes instead of probes are also available if this argument is set to "GENE". This conversion was made using the \code{nsFilter} function from Bioconductors \pkg{genefilter} package.
  			}
  			\item{\code{norm = "ORIGINAL"}}{Type of normalization to use when pre-processing a dataset.
  			 
  			Possible normalizations: "ORIGINAL", "FRMA"[1], "SCAN"[2].}
 			 \item{\code{curation}}{Specific curation used to annotate a dataset.
A curation is identified by a InSilico DB Curation identifier. You can annotate datasets yourself at \url{https://insilicodb.com/app/browse} If not defined, the prefered curation of specified dataset will be used.}   
  			\item{\code{timeout = 120}}{Time (in seconds) to wait for the dataset, if it has to be generated.}
		}
 	}
 }
 \value{
 A Bioconductors ExpressionSet.
 }
 \seealso{
 \code{\link{getDatasetInfo}}
 }
\examples{
InSilicoLogin("rpackage_tester@insilicodb.com", "5c4d0b231e5cba4a0bc54783b385cc9a");
dataset.id <- "GSE4635";
platform.id <- getPlatforms(dataset.id);
eset <- getDataset(dataset.id, platform.id[[1]],
                   norm = "ORIGINAL", features = "PROBE");
print(dim(eset));
## Features  Samples 
##    22215        8 
eset <- getDataset( dataset.id, platform.id[[1]],
                   norm = "ORIGINAL", features = "GENE");
print(dim(eset));
## Features  Samples 
##    12698        8 
}

\references{
[1] MN. McCall, BM. Bolstad, and RA. Irizarry, Frozen Robust Multi-Array Analysis (fRMA),
  \emph{Biostatistics}, vol. 11, no. 2, pp. 242-253 , 2008.
  
[2] SR. Piccolo, Y. Sun, JD. Campbell, ME. Lenburg, AH. Bild, and WE. Johnson, A single-sample microarray
  normalization method to facilitate personalized-medicine workflows, \emph{Genomics}, vol. 100, no. 6, pp. 337-344, 2012.
 }
